@@ -23,7 +23,8 @@ xmlfiles = ("env_archive", "env_batch", "env_build", "env_case",
 
 rcfiles = ("seq_maps",)
 
-makefiles = ("Depends.intel",)
+#makefiles = ("Depends.intel",)
+makefiles = ("Depends",)
 
 exclude_zipfiles = []
 excludes_casedocs = ["env_mach_specific.xml~"]
@@ -132,10 +133,10 @@ class PACEDB(App):
 
         jsondata = json.dumps(mkitems)
 
-        if self.verify_db:
-            mk = self.session.query(MakefileInputs).filter_by(
-                    expid=expid, name=name).first()
+        mk = self.session.query(MakefileInputs).filter_by(
+                expid=expid, name=name).first()
 
+        if self.verify_db:
             if not mk or jsondata != mk.data:
                 print("#######################################################")
                 print("makefile verification failure: expid=%d, name=%s" % (expid, name))
@@ -145,8 +146,12 @@ class PACEDB(App):
                 print("From database:")
                 print(mk.data if mk else mk)
         else:
-            mk = MakefileInputs(expid, name, jsondata)
-            self.session.add(mk)
+            if mk:
+                print("Insertion is discarded due to dupulication: expid=%d, name=%s" % (expid, name))
+
+            else:
+                mk = MakefileInputs(expid, name, jsondata)
+                self.session.add(mk)
 
 
     def loaddb_rcfile(self, expid, name, rcpath):
@@ -165,10 +170,10 @@ class PACEDB(App):
 
         jsondata = "{%s}" % ",".join(rcitems) 
 
-        if self.verify_db:
-            rc = self.session.query(RCInputs).filter_by(
-                    expid=expid, name=name).first()
+        rc = self.session.query(RCInputs).filter_by(
+                expid=expid, name=name).first()
 
+        if self.verify_db:
             #e3smdump = json.dumps(rc.data, sort_keys=True) if rc else ""
             #dbdump = json.dumps(jsondata, sort_keys=True)
             #if e3smdump != dbdump:
@@ -183,8 +188,12 @@ class PACEDB(App):
                 #print(dbdump)
                 print(rc.data if rc else rc)
         else:
-            rc = RCInputs(expid, name, jsondata)
-            self.session.add(rc)
+            if rc:
+                print("Insertion is discarded due to dupulication: expid=%d, name=%s" % (expid, name))
+
+            else:
+                rc = RCInputs(expid, name, jsondata)
+                self.session.add(rc)
 
     def loaddb_xmlfile(self, expid, name, xmlpath):
  
@@ -199,10 +208,10 @@ class PACEDB(App):
 
             jsondata = fwds["data"]
 
-            if self.verify_db:
-                xml = self.session.query(XMLInputs).filter_by(
-                        expid=expid, name=name).first()
+            xml = self.session.query(XMLInputs).filter_by(
+                    expid=expid, name=name).first()
 
+            if self.verify_db:
                 #e3smdump = json.dumps(xml.data, sort_keys=True) if xml else ""
                 #dbdump = json.dumps(jsondata, sort_keys=True)
                 #if e3smdump != dbdump:
@@ -217,8 +226,12 @@ class PACEDB(App):
                     #print(dbdump)
                     print(xml.data if xml else xml)
             else:
-                xml = XMLInputs(expid, name, jsondata)
-                self.session.add(xml)
+                if xml:
+                    print("Insertion is discarded due to dupulication: expid=%d, name=%s" % (expid, name))
+
+                else:
+                    xml = XMLInputs(expid, name, jsondata)
+                    self.session.add(xml)
 
         except ExpatError as err:
             print("Warning: %s" % str(err))
@@ -257,10 +270,10 @@ class PACEDB(App):
             import pdb; pdb.set_trace()
             print(err)
 
-        if self.verify_db:
-            nml = self.session.query(NamelistInputs).filter_by(
+        nml = self.session.query(NamelistInputs).filter_by(
                     expid=expid, name=name).first()
 
+        if self.verify_db:
             #e3smdump = json.dumps(nml.data, sort_keys=True) if nml else ""
             #dbdump = json.dumps(jsondata, sort_keys=True)
             #if e3smdump != dbdump:
@@ -276,8 +289,12 @@ class PACEDB(App):
                 print(nml.data if nml else nml)
 
         elif jsondata:
-            nml = NamelistInputs(expid, name, jsondata)
-            self.session.add(nml)
+            if nml:
+                print("Insertion is discarded due to dupulication: expid=%d, name=%s" % (expid, name))
+
+            else:
+                nml = NamelistInputs(expid, name, jsondata)
+                self.session.add(nml)
 
     def loaddb_casedocs(self, expid, casedocpath):
 
@@ -288,22 +305,31 @@ class PACEDB(App):
                 continue
 
             if os.path.isfile(path) and ext == ".gz":
-                prefix, _ = basename.split(".", 1)
+                #prefix, _ = basename.split(".", 1)
+                nameseq = []
+                for n in basename.split("."):
+                    if n.isdigit():
+                        break
+                    nameseq.append(n)
+                name = ".".join(nameseq)
 
-                if prefix in namelists:
-                    self.loaddb_namelist(expid, prefix, path)
+                if nameseq[0] in namelists:
+                    self.loaddb_namelist(expid, name, path)
 
-                elif prefix in xmlfiles:
-                    self.loaddb_xmlfile(expid, prefix, path)
+                elif nameseq[0] in xmlfiles:
+                    self.loaddb_xmlfile(expid, name, path)
 
-                elif prefix in rcfiles:
-                    self.loaddb_rcfile(expid, prefix, path)
+                elif nameseq[0] in rcfiles:
+                    self.loaddb_rcfile(expid, name, path)
 
-                elif any(basename.startswith(p) for p in makefiles):
-                    for makefile in makefiles:
-                        if basename.startswith(makefile):
-                            self.loaddb_makefile(expid, makefile, path)
-                            break
+                elif nameseq[0] in makefiles:
+                    self.loaddb_makefile(expid, name, path)
+
+#                elif any(basename.startswith(p) for p in makefiles):
+#                    for makefile in makefiles:
+#                        if basename.startswith(makefile):
+#                            self.loaddb_makefile(expid, makefile, path)
+#                            break
                 else:
                     pass
                     #print("Warning: %s is not parsed." % basename)
